InstancesCount class
Describes how many instances a stack has for each status.
Constructors
- InstancesCount({int? assigning, int? booting, int? connectionLost, int? deregistering, int? online, int? pending, int? rebooting, int? registered, int? registering, int? requested, int? runningSetup, int? setupFailed, int? shuttingDown, int? startFailed, int? stopFailed, int? stopped, int? stopping, int? terminated, int? terminating, int? unassigning})
-
InstancesCount.fromJson(Map<
String, dynamic> json) -
factory
Properties
- assigning → int?
-
The number of instances in the Assigning state.
final
- booting → int?
-
The number of instances with
bootingstatus.final - connectionLost → int?
-
The number of instances with
connection_loststatus.final - deregistering → int?
-
The number of instances in the Deregistering state.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- online → int?
-
The number of instances with
onlinestatus.final - pending → int?
-
The number of instances with
pendingstatus.final - rebooting → int?
-
The number of instances with
rebootingstatus.final - registered → int?
-
The number of instances in the Registered state.
final
- registering → int?
-
The number of instances in the Registering state.
final
- requested → int?
-
The number of instances with
requestedstatus.final - runningSetup → int?
-
The number of instances with
running_setupstatus.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setupFailed → int?
-
The number of instances with
setup_failedstatus.final - shuttingDown → int?
-
The number of instances with
shutting_downstatus.final - startFailed → int?
-
The number of instances with
start_failedstatus.final - stopFailed → int?
-
The number of instances with
stop_failedstatus.final - stopped → int?
-
The number of instances with
stoppedstatus.final - stopping → int?
-
The number of instances with
stoppingstatus.final - terminated → int?
-
The number of instances with
terminatedstatus.final - terminating → int?
-
The number of instances with
terminatingstatus.final - unassigning → int?
-
The number of instances in the Unassigning state.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited